import { default as GetRowsRequest } from './types/GetRowsRequest';
import { default as LoadSuccessParams } from './types/LoadSuccessParams';
interface Props {
    /** Unique identifier for the table */
    id: string;
    /** Title of the table */
    title: string;
    /** Determines whether to show search functionality */
    showSearch: boolean;
    /**
     * Array of header configurations for the table columns
     * field: name corresponding to the data property
     * sortable: Enables sorting for this column (Optional, default false)
     * cellRenderer: Custom cell renderer template, Add your Component here. see story
     * filter: Add AG Grid filer or RadioFilter
     * filterItems: Items for Filter e.g. RadioFilter
     */
    headers: {
        field: string;
        sortable?: boolean;
        cellRenderer?: {
            template: string;
        };
        filter?: any;
        filterItems: {
            values: {
                value: string;
                name: string;
            }[];
        };
    }[];
    /**
     * Function to fetch rows based on request parameters and search text
     * The keys of the data are each the value of the field of the header.   * @param request - Object containing pagination and sorting info
     * @param searchText - Current search query string
     * @returns LoadSuccessParams - Object with row data and total count
     */
    getRows: (request: GetRowsRequest, searchText: string) => LoadSuccessParams;
    /** Number of rows to display per page (Do not change here in the storybook) */
    paginationPageSize: number;
}
declare const _default: import('vue').DefineComponent<Props, {}, {}, {}, {}, import('vue').ComponentOptionsMixin, import('vue').ComponentOptionsMixin, {}, string, import('vue').PublicProps, Readonly<Props> & Readonly<{}>, {
    title: string;
    showSearch: boolean;
    paginationPageSize: number;
}, {}, {}, {}, string, import('vue').ComponentProvideOptions, false, {}, any>;
export default _default;
